"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from amds.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UploadFileRequestBodyTypedDict(TypedDict):
    content: NotRequired[str]
    format_: NotRequired[str]
    type: NotRequired[str]


class UploadFileRequestBody(BaseModel):
    content: Optional[str] = None

    format_: Annotated[Optional[str], pydantic.Field(alias="format")] = None

    type: Optional[str] = None


class UploadFileRequestTypedDict(TypedDict):
    server_name: str
    path: str
    request_body: NotRequired[UploadFileRequestBodyTypedDict]


class UploadFileRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    path: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Optional[UploadFileRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None


class UploadFileContentTypedDict(TypedDict):
    content: NotRequired[Nullable[Any]]
    created: NotRequired[str]
    format_: NotRequired[Nullable[Any]]
    last_modified: NotRequired[str]
    mimetype: NotRequired[str]
    name: NotRequired[str]
    path: NotRequired[str]
    server_path: NotRequired[str]
    size: NotRequired[float]
    type: NotRequired[str]
    writable: NotRequired[bool]


class UploadFileContent(BaseModel):
    content: OptionalNullable[Any] = UNSET

    created: Optional[str] = None

    format_: Annotated[OptionalNullable[Any], pydantic.Field(alias="format")] = UNSET

    last_modified: Optional[str] = None

    mimetype: Optional[str] = None

    name: Optional[str] = None

    path: Optional[str] = None

    server_path: Annotated[Optional[str], pydantic.Field(alias="serverPath")] = None

    size: Optional[float] = None

    type: Optional[str] = None

    writable: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "content",
            "created",
            "format",
            "last_modified",
            "mimetype",
            "name",
            "path",
            "serverPath",
            "size",
            "type",
            "writable",
        ]
        nullable_fields = ["content", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadFileResponseBodyTypedDict(TypedDict):
    r"""Upload File"""

    content: NotRequired[UploadFileContentTypedDict]
    status: NotRequired[str]


class UploadFileResponseBody(BaseModel):
    r"""Upload File"""

    content: Optional[UploadFileContent] = None

    status: Optional[str] = None


class UploadFileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: UploadFileResponseBodyTypedDict


class UploadFileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: UploadFileResponseBody



import click
import sys
import json
from ..utils import print_json

@click.group()
def alph():
    """AI language model operations"""
    pass

@alph.command('gpt4o-mini')
@click.option('--server-name', required=True, help='Name of the server')
@click.option('--message', required=True, help='Message to send to the model')
@click.pass_obj
def gpt4o_mini(client, server_name, message):
    """Use gpt-4o-mini model"""
    with client as c:
        res = c.alph.gpt4o_mini(
            server_name=server_name,
            messages=[{"content": message, "role": "user"}]
        )
        
        # Access the raw response object
        raw_response = res.raw_response
        if raw_response.encoding is None:
            raw_response.encoding = 'utf-8'

        full_output = []
        try:
            for line in raw_response.iter_lines(decode_unicode=True):
                if line:
                    split_line = line.split(':', 1)
                    try:
                        tool_call = json.loads(split_line[1])
                        cleaned_line = json.dumps(tool_call.get('result', ''), indent=4)
                        sys.stdout.write('\nAnalyzing...\n')
                        sys.stdout.write(cleaned_line)
                    except:
                        cleaned_line = split_line[1].replace('"', '')
                        if r'\n' in cleaned_line:
                            sys.stdout.write(cleaned_line.replace(r'\n', ''))
                        else:
                            sys.stdout.write(cleaned_line)
                    full_output.append(cleaned_line)
            sys.stdout.write('\n')
        except ValueError:
            sys.stdout.write('Response encoded incorrectly.\n')
            if hasattr(res, 'text'):
                sys.stdout.write(res.text)
                sys.stdout.write('\n')
            else:
                print_json(res.model_dump())

@alph.command('gpt4o')
@click.option('--server-name', required=True, help='Name of the server')
@click.option('--message', required=True, help='Message to send to the model')
@click.pass_obj
def gpt4o(client, server_name, message):
    """Use gpt-4o model"""
    with client as c:
        res = c.alph.gpt4o(
            server_name=server_name,
            messages=[{"content": message, "role": "user"}]
        )
        if hasattr(res, 'text'):
            sys.stdout.write(res.text)
            sys.stdout.write('\n')
        else:
            print_json(res.model_dump())

@alph.command('gpt4')
@click.option('--server-name', required=True, help='Name of the server')
@click.option('--message', required=True, help='Message to send to the model')
@click.pass_obj
def gpt4(client, server_name, message):
    """Use gpt-4 model"""
    with client as c:
        res = c.alph.gpt4(
            server_name=server_name,
            messages=[{"content": message, "role": "user"}]
        )
        if hasattr(res, 'text'):
            sys.stdout.write(res.text)
            sys.stdout.write('\n')
        else:
            print_json(res.model_dump())

@alph.command('claude35-haiku')
@click.option('--server-name', required=True, help='Name of the server')
@click.option('--message', required=True, help='Message to send to the model')
@click.pass_obj
def claude35_haiku(client, server_name, message):
    """Use claude-3.5-haiku model"""
    with client as c:
        res = c.alph.claude35_haiku(
            server_name=server_name,
            messages=[{"content": message, "role": "user"}]
        )
        if hasattr(res, 'text'):
            sys.stdout.write(res.text)
            sys.stdout.write('\n')
        else:
            print_json(res.model_dump())

@alph.command('claude35-sonnet')
@click.option('--server-name', required=True, help='Name of the server')
@click.option('--message', required=True, help='Message to send to the model')
@click.pass_obj
def claude35_sonnet(client, server_name, message):
    """Use claude-3.5-sonnet model"""
    with client as c:
        res = c.alph.claude35_sonnet(
            server_name=server_name,
            messages=[{"content": message, "role": "user"}]
        )
        if hasattr(res, 'text'):
            sys.stdout.write(res.text)
            sys.stdout.write('\n')
        else:
            print_json(res.model_dump())



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Gpt4oMessagesTypedDict(TypedDict):
    content: NotRequired[str]
    role: NotRequired[str]


class Gpt4oMessages(BaseModel):
    content: Optional[str] = None

    role: Optional[str] = None


class Gpt4oRequestBodyTypedDict(TypedDict):
    messages: NotRequired[List[Gpt4oMessagesTypedDict]]


class Gpt4oRequestBody(BaseModel):
    messages: Optional[List[Gpt4oMessages]] = None


class Gpt4oRequestTypedDict(TypedDict):
    server_name: str
    request_body: NotRequired[Gpt4oRequestBodyTypedDict]


class Gpt4oRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Optional[Gpt4oRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None


class Gpt4oResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class Gpt4oResponse(BaseModel):
    headers: Dict[str, List[str]]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class StopServerRequestBodyTypedDict(TypedDict):
    stop: NotRequired[bool]


class StopServerRequestBody(BaseModel):
    stop: Optional[bool] = None


class StopServerRequestTypedDict(TypedDict):
    server_name: str
    request_body: NotRequired[StopServerRequestBodyTypedDict]


class StopServerRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Optional[StopServerRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None


class StopServerResponseBodyTypedDict(TypedDict):
    r"""Stop Server"""

    message: NotRequired[str]
    status: NotRequired[str]


class StopServerResponseBody(BaseModel):
    r"""Stop Server"""

    message: Optional[str] = None

    status: Optional[str] = None


class StopServerResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: StopServerResponseBodyTypedDict


class StopServerResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: StopServerResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetFileRequestTypedDict(TypedDict):
    server_name: str
    path: str


class GetFileRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    path: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class ContentTypedDict(TypedDict):
    content: NotRequired[str]
    created: NotRequired[str]
    format_: NotRequired[str]
    last_modified: NotRequired[str]
    mimetype: NotRequired[str]
    name: NotRequired[str]
    path: NotRequired[str]
    server_path: NotRequired[str]
    size: NotRequired[float]
    type: NotRequired[str]
    writable: NotRequired[bool]


class Content(BaseModel):
    content: Optional[str] = None

    created: Optional[str] = None

    format_: Annotated[Optional[str], pydantic.Field(alias="format")] = None

    last_modified: Optional[str] = None

    mimetype: Optional[str] = None

    name: Optional[str] = None

    path: Optional[str] = None

    server_path: Annotated[Optional[str], pydantic.Field(alias="serverPath")] = None

    size: Optional[float] = None

    type: Optional[str] = None

    writable: Optional[bool] = None


class GetFileResponseBodyTypedDict(TypedDict):
    r"""Get File"""

    content: NotRequired[ContentTypedDict]
    status: NotRequired[str]


class GetFileResponseBody(BaseModel):
    r"""Get File"""

    content: Optional[Content] = None

    status: Optional[str] = None


class GetFileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetFileResponseBodyTypedDict


class GetFileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetFileResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from typing import Dict, List, Optional
from typing_extensions import NotRequired, TypedDict


class CreateServerRequestBodyTypedDict(TypedDict):
    environment: NotRequired[str]
    port: NotRequired[float]
    server_name: NotRequired[str]
    server_request: NotRequired[str]


class CreateServerRequestBody(BaseModel):
    environment: Optional[str] = None

    port: Optional[float] = None

    server_name: Optional[str] = None

    server_request: Optional[str] = None


class CreateServerResponseBodyTypedDict(TypedDict):
    r"""Create Server"""

    environment: NotRequired[str]
    hourly_rate: NotRequired[float]
    port_forward_url: NotRequired[str]
    server_name: NotRequired[str]
    server_request: NotRequired[str]
    status: NotRequired[str]
    url: NotRequired[str]


class CreateServerResponseBody(BaseModel):
    r"""Create Server"""

    environment: Optional[str] = None

    hourly_rate: Optional[float] = None

    port_forward_url: Optional[str] = None

    server_name: Optional[str] = None

    server_request: Optional[str] = None

    status: Optional[str] = None

    url: Optional[str] = None


class CreateServerResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: CreateServerResponseBodyTypedDict


class CreateServerResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: CreateServerResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteServerRequestTypedDict(TypedDict):
    server_name: str


class DeleteServerRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class DeleteServerResponseBodyTypedDict(TypedDict):
    r"""Delete Server"""

    message: NotRequired[str]
    status: NotRequired[str]


class DeleteServerResponseBody(BaseModel):
    r"""Delete Server"""

    message: Optional[str] = None

    status: Optional[str] = None


class DeleteServerResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DeleteServerResponseBodyTypedDict


class DeleteServerResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DeleteServerResponseBody



import click
from ..utils import print_json

@click.group()
def compute():
    """Manage compute resources"""
    pass

@compute.command('list')
@click.pass_obj
def list_compute(client):
    """List compute information"""
    with client as c:
        res = c.compute.get()
        print_json(res.model_dump()) 